@@ -1,5 +1,7 @@
 package POEx::ZMQ::FFI::Cached;
-$POEx::ZMQ::FFI::Cached::VERSION = '0.004001';
+$POEx::ZMQ::FFI::Cached::VERSION = '0.005001';
+# A simplistic way to share POEx::ZMQ::FFI::Callable objects
+
 use Carp;
 use strictures 1;
 
@@ -33,6 +35,8 @@ sub clear {
   delete $Cache{ $classtype . $soname }
 }
 
+sub clear_all { %Cache = () }
+
 1;
 
 =pod
