@@ -1,5 +1,5 @@
 package POEx::ZMQ::FFI::Role::ErrorChecking;
-$POEx::ZMQ::FFI::Role::ErrorChecking::VERSION = '0.004001';
+$POEx::ZMQ::FFI::Role::ErrorChecking::VERSION = '0.005001';
 use v5.10;
 use Carp 'cluck', 'confess';
 use strictures 1;
@@ -48,34 +48,33 @@ sub _build_ffi {
 sub errno  { $_[0]->err_handler->zmq_errno }
 sub errstr { $_[0]->err_handler->zmq_strerror( $_[1] // $_[0]->errno ) }
 
-sub _build_zmq_error {
-  my ($self, $call) = @_;
-  my $errno  = $self->errno;
-  my $errstr = $self->errstr($errno);
+sub _create_zmq_error {
+  my $errno  = $_[0]->errno;
+  my $errstr = $_[0]->errstr($errno);
   POEx::ZMQ::FFI::Error->new(
     message  => $errstr,
     errno    => $errno,
-    function => $call,
+    function => ($_[1] // confess "Missing function name"),
   ) 
 }
 
 sub throw_zmq_error {
-  $_[0]->_build_zmq_error(@_[1 .. $#_])->throw
+  $_[0]->_create_zmq_error(@_[1 .. $#_])->throw
 }
 
 sub throw_if_error {
   confess "Expected function name and return code"
-    unless defined $_[1] and defined $_[2];
+    unless defined $_[2];
   $_[0]->throw_zmq_error($_[1]) if $_[2] == -1;
   $_[0]
 }
 
 sub warn_if_error {
   confess "Expected function name and return code"
-    unless defined $_[1] and defined $_[2];
+    unless defined $_[2];
 
   if ($_[2] == -1) {
-    my $err = $_[0]->_build_zmq_error($_[1]);
+    my $err = $_[0]->_create_zmq_error($_[1]);
     cluck $err . "\n";
     return
   }
