@@ -1,5 +1,5 @@
 package POEx::ZMQ::FFI::Socket;
-$POEx::ZMQ::FFI::Socket::VERSION = '0.004001';
+$POEx::ZMQ::FFI::Socket::VERSION = '0.005001';
 use v5.10;
 use Carp;
 use strictures 1;
@@ -265,7 +265,7 @@ sub DEMOLISH {
 
 
 our $KnownTypes = hash;
-$KnownTypes->set( $_ => 'int' ) for (
+$KnownTypes->set( $_, 'int' ) for (
   ZMQ_BACKLOG,            #
   ZMQ_CONFLATE,           # 4.0
   ZMQ_DELAY_ATTACH_ON_CONNECT,
@@ -296,11 +296,12 @@ $KnownTypes->set( $_ => 'int' ) for (
   ZMQ_SNDBUF,             #
   ZMQ_XPUB_VERBOSE,       #
 );
-$KnownTypes->set( $_ => 'uint64' ) for (
+$KnownTypes->set( $_, 'uint64' ) for (
   ZMQ_AFFINITY,           #
   ZMQ_MAXMSGSIZE,         #
 );
-$KnownTypes->set( $_ => 'binary' ) for (
+# ... doesn't really matter if we differentiate here, but:
+$KnownTypes->set( $_, 'binary' ) for (
   ZMQ_IDENTITY,           #
   ZMQ_SUBSCRIBE,          #
   ZMQ_UNSUBSCRIBE,        #
@@ -309,7 +310,7 @@ $KnownTypes->set( $_ => 'binary' ) for (
   ZMQ_CURVE_SERVERKEY,    # 4.0
   ZMQ_TCP_ACCEPT_FILTER,  #
 );
-$KnownTypes->set( $_ => 'string' ) for (
+$KnownTypes->set( $_, 'string' ) for (
   ZMQ_LAST_ENDPOINT,      #
   ZMQ_PLAIN_USERNAME,     # 4.0
   ZMQ_PLAIN_PASSWORD,     # 4.0
@@ -482,6 +483,13 @@ POEx::ZMQ::FFI::Socket
 
 An object representing a ZeroMQ socket; used internally by L<POEx::ZMQ>.
 
+These are typically created by your L<POEx::ZMQ::Socket> instance and are
+accessible via the C<zsock> attribute:
+
+  my $backend = $my_sock->zsock;
+  my $sock_ptr = $backend->get_raw_socket;
+  # ... make some manual FFI::Raw calls ...
+
 This is essentially a minimalist reimplementation of Dylan Cali's L<ZMQ::FFI>;
 see L<ZMQ::FFI> for a ZeroMQ FFI implementation intended for use outside
 L<POE>.
